# -*- coding: utf-8 -*-

from django_six import MiddlewareMixin

class BrowserLanguageDetectionMiddleware(MiddlewareMixin):
    def process_request(self, request):
        lng = request.META.get('LANGUAGE', request.META.get('LANG'))
        if lng:
            request.browser_language = lng
        else:
            request.browser_language = None
        
        return None



# -*- coding: utf-8 -*-

from setuptools import setup

version = '1.0.0'


setup(
    name='django-language-detect',
    version=version,
    keywords='django-language-detect',
    description='Django browser language detect',
    long_description=open('README.rst').read(),

    url='https://github.com/wmarquardt/django-language-detect',

    author='William Marquardt',
    author_email='williammqt@gmail.com',

    packages=['language_detect'],
    py_modules=[],
    install_requires=['django-six'],

    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Office/Business :: Financial :: Spreadsheet',
    ],
)
